An R implementation and enhancement of the Dynamic TOPMODEL semi-distributed hydrological model originally proposed by Beven and Freer (2001) tools:::Rd_expr_doi("10.1002/hyp.252"). The 'dynatop' package implements code for simulating models which can be created using the 'dynatopGIS' package.
Maintainer: Paul Smith paul@waternumbers.co.uk (ORCID)
Authors:
Peter Metcalfe
Useful links: